@@ -22,6 +22,8 @@ from base64 import b64decode
 from datajoint.errors import IntegrityError
 from datajoint.table import foreign_key_error_regexp
 from datajoint.utils import to_camel_case
+import traceback
+import time
 
 app = Flask(__name__)
 # Check if PRIVATE_KEY and PUBIC_KEY is set, if not generate them.
@@ -124,7 +126,7 @@ def api_version() -> str:
             Content-Type: application/json
 
             {
-                "version": "0.6.0"
+                "version": "0.6.1"
             }
 
         :statuscode 200: No error.
@@ -233,6 +235,7 @@ def login() -> dict:
                 auth_info = dict(
                     jwt=result.json()["access_token"], id=result.json()["id_token"]
                 )
+                time.sleep(1)
                 connect_creds = {
                     "databaseAddress": request.args["database_host"],
                     "username": jwt.decode(
@@ -280,8 +283,8 @@ def login() -> dict:
                 else:
                     raise e
             return dict(**auth_info)
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
 
 
 @app.route(f"{environ.get('PHARUS_PREFIX', '')}/schema", methods=["GET"])
@@ -342,8 +345,8 @@ def schema(connection: dj.Connection) -> dict:
         try:
             schemas_name = _DJConnector._list_schemas(connection)
             return dict(schemaNames=schemas_name)
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
 
 
 @app.route(
@@ -419,8 +422,8 @@ def table(
         try:
             tables_dict_list = _DJConnector._list_tables(connection, schema_name)
             return dict(tableTypes=tables_dict_list)
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
 
 
 @app.route(
@@ -741,24 +744,24 @@ def record(
             return dict(
                 recordHeader=record_header, records=table_tuples, totalCount=total_count
             )
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
     elif request.method == "POST":
         try:
             _DJConnector._insert_tuple(
                 connection, schema_name, table_name, request.json["records"]
             )
             return "Insert Successful"
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
     elif request.method == "PATCH":
         try:
             _DJConnector._update_tuple(
                 connection, schema_name, table_name, request.json["records"]
             )
             return "Update Successful"
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
     elif request.method == "DELETE":
         try:
             _DJConnector._delete_records(
@@ -788,8 +791,8 @@ def record(
                 ),
                 409,
             )
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
 
 
 @app.route(
@@ -871,8 +874,8 @@ def definition(
                 connection, schema_name, table_name
             )
             return table_definition
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
 
 
 @app.route(
@@ -1050,8 +1053,8 @@ def attribute(
                 attributeHeaders=attributes_meta["attribute_headers"],
                 attributes=attributes_meta["attributes"],
             )
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
 
 
 @app.route(
@@ -1157,15 +1160,15 @@ def dependency(
                 ),
             )
             return dict(dependencies=dependencies)
-        except Exception as e:
-            return str(e), 500
+        except Exception:
+            return traceback.format_exc(), 500
 
 
 def run():
     """
     Starts API server.
     """
-    app.run(host="0.0.0.0", port=environ.get("PHARUS_PORT", 5000), threaded=True)
+    app.run(host="0.0.0.0", port=environ.get("PHARUS_PORT", 5000), threaded=False)
 
 
 if __name__ == "__main__":
